@@ -194,11 +194,10 @@ class trsf_parameters(object):
         Args:
             prefix (str): The prefix to add in front of the path
         """
-        from os import path
-        self.projection_path = str(Path(prefix) / self.projection_path) + path.sep
-        self.path_to_data = str(Path(prefix) / self.path_to_data) + path.sep
-        self.trsf_folder = str(Path(prefix) / self.trsf_folder) + path.sep
-        self.output_format = str(Path(prefix) / self.output_format) + path.sep
+        self.projection_path = os.path.join(prefix, self.projection_path) + os.path.sep
+        self.path_to_data = os.path.join(prefix, self.path_to_data) + os.path.sep
+        self.trsf_folder = os.path.join(prefix, self.trsf_folder) + os.path.sep
+        self.output_format = os.path.join(prefix, self.output_format) + os.path.sep
 
     def __init__(self, file_name: str):
         if not isinstance(file_name, dict):
@@ -253,8 +252,18 @@ class trsf_parameters(object):
 
         self.__dict__.update(param_dict)
         self.voxel_size = tuple(self.voxel_size)
+        if not hasattr(self, "voxel_size_out"):
+            self.voxel_size_out = self.voxel_size
+        else:
+            self.voxel_size_out = tuple(self.voxel_size_out)
         self.origin_file_name = file_name
 
+        if 0 < len(self.projection_path) and self.projection_path[-1] != os.path.sep:
+            self.projection_path = self.projection_path + os.path.sep
+        if 0 < len(self.path_to_data) and self.path_to_data[-1] != os.path.sep:
+            self.path_to_data = self.path_to_data + os.path.sep
+        if 0 < len(self.trsf_folder) and self.trsf_folder[-1] != os.path.sep:
+            self.trsf_folder = self.trsf_folder + os.path.sep
 
 class TimeRegistration:
     @staticmethod
@@ -307,13 +316,13 @@ class TimeRegistration:
         if not make:
             print("trsf tp %d-%d not done" % (t1, t2))
             np.savetxt(
-                p.trsf_folder + "t%06d-%06d.txt" % (t_flo, t_ref),
+                os.path.join(p.trsf_folder, "t%06d-%06d.txt" % (t_flo, t_ref)),
                 np.identity(4),
             )
         elif t_flo != t_ref and (
             p.recompute
             or not os.path.exists(
-                p.trsf_folder + "t%06d-%06d.txt" % (t_flo, t_ref)
+                os.path.join(p.trsf_folder, "t%06d-%06d.txt" % (t_flo, t_ref))
             )
         ):
             if p.low_th is not None and 0<p.low_th:
@@ -337,8 +346,7 @@ class TimeRegistration:
                             p.registration_depth_end,
                         )
                         + " -res-trsf "
-                        + p.trsf_folder
-                        + "t%06d-%06d-tmp.txt" % (t_flo, t_ref)
+                        + os.path.join(p.trsf_folder, "t%06d-%06d-tmp.txt" % (t_flo, t_ref))
                         + th)
                     call(
                         self.path_to_bin
@@ -354,38 +362,17 @@ class TimeRegistration:
                             p.registration_depth_end,
                         )
                         + " -res-trsf "
-                        + p.trsf_folder
-                        + "t%06d-%06d-tmp.txt" % (t_flo, t_ref)
+                        + os.path.join(p.trsf_folder, "t%06d-%06d-tmp.txt" % (t_flo, t_ref))
                         + th,
                         shell=True,
                     )
                     pre_trsf = (
                         " -init-trsf "
-                        + p.trsf_folder
-                        + "t%06d-%06d-tmp.txt" % (t_flo, t_ref)
+                        + os.path.join(p.trsf_folder, "t%06d-%06d-tmp.txt" % (t_flo, t_ref))
                         + " -composition-with-initial "
                     )
                 else:
                     pre_trsf = ""
-                print(
-                    self.path_to_bin
-                    + "blockmatching -ref "
-                    + p_im_ref
-                    + " -flo "
-                    + p_im_flo
-                    + pre_trsf
-                    + " -reference-voxel %f %f %f" % p.voxel_size
-                    + " -floating-voxel %f %f %f" % p.voxel_size
-                    + " -trsf-type %s -py-hl %d -py-ll %d"
-                    % (
-                        p.trsf_type,
-                        p.registration_depth_start,
-                        p.registration_depth_end,
-                    )
-                    + " -res-trsf "
-                    + p.trsf_folder
-                    + "t%06d-%06d.txt" % (t_flo, t_ref)
-                    + th,)
                 call(
                     self.path_to_bin
                     + "blockmatching -ref "
@@ -402,8 +389,7 @@ class TimeRegistration:
                         p.registration_depth_end,
                     )
                     + " -res-trsf "
-                    + p.trsf_folder
-                    + "t%06d-%06d.txt" % (t_flo, t_ref)
+                    + os.path.join(p.trsf_folder, "t%06d-%06d.txt" % (t_flo, t_ref))
                     + th,
                     shell=True,
                 )
@@ -415,8 +401,7 @@ class TimeRegistration:
                 if p.keep_vectorfield and pyklb_found:
                     res_trsf = (
                         " -composition-with-initial -res-trsf "
-                        + p.trsf_folder
-                        + "t%06d-%06d.klb" % (t_flo, t_ref)
+                        + os.path.join(p.trsf_folder, "t%06d-%06d.klb" % (t_flo, t_ref))
                     )
                 else:
                     res_trsf = ""
@@ -435,8 +420,7 @@ class TimeRegistration:
                     + " -trsf-type affine -py-hl %d -py-ll %d"
                     % (p.registration_depth_start, p.registration_depth_end)
                     + " -res-trsf "
-                    + p.trsf_folder
-                    + "t%06d-%06d.txt" % (t_flo, t_ref)
+                    + os.path.join(p.trsf_folder, "t%06d-%06d.txt" % (t_flo, t_ref))
                     + th,
                     shell=True,
                 )
@@ -447,8 +431,7 @@ class TimeRegistration:
                     + " -flo "
                     + p_im_flo
                     + " -init-trsf "
-                    + p.trsf_folder
-                    + "t%06d-%06d.txt" % (t_flo, t_ref)
+                    + os.path.join(p.trsf_folder, "t%06d-%06d.txt" % (t_flo, t_ref))
                     + res
                     + " -reference-voxel %f %f %f" % p.voxel_size
                     + " -floating-voxel %f %f %f" % p.voxel_size
@@ -634,9 +617,9 @@ class TimeRegistration:
             else:
                 p.A0_out = p.output_format
         else:
-            p.A0_out = p.path_to_data + p.file_name.replace(
+            p.A0_out = os.path.join(p.path_to_data, p.file_name.replace(
                 p.im_ext, p.suffix + "." + p.im_ext
-            )
+            ))
 
         # Time points to work with
         p.time_points = np.array(
@@ -655,7 +638,7 @@ class TimeRegistration:
         if not p.sequential:
             p.ref_path = p.A0.format(t=p.ref_TP)
         if p.apply_trsf:
-            for i, t in enumerate(sorted(p.time_points)):
+            for t in sorted(p.time_points):
                 folder_tmp = os.path.split(p.A0_out.format(t=t))[0]
                 if not os.path.exists(folder_tmp):
                     os.makedirs(folder_tmp)
@@ -737,7 +720,7 @@ class TimeRegistration:
         Z_T = []
         T = []
         for t in p.to_register:
-            trsf_p = p.trsf_folder + trsf_fmt.format(flo=t, ref=p.ref_TP)
+            trsf_p = os.path.join(p.trsf_folder, trsf_fmt.format(flo=t, ref=p.ref_TP))
             trsf = self.read_trsf(trsf_p)
             T += [t]
             X_T += [trsf[0, -1]]
@@ -753,7 +736,7 @@ class TimeRegistration:
             mat[1, -1] = Y_interp(t)
             mat[2, -1] = Z_interp(t)
             np.savetxt(
-                p.trsf_folder + new_trsf_fmt.format(flo=t, ref=p.ref_TP), mat
+                os.path.join(p.trsf_folder, new_trsf_fmt.format(flo=t, ref=p.ref_TP), mat)
             )
         trsf_fmt = new_trsf_fmt
         return trsf_fmt
@@ -780,10 +763,10 @@ class TimeRegistration:
         im = SpatialImage(np.ones(im_shape), dtype=np.uint8)
         im.voxelsize = p.voxel_size
         if pyklb_found:
-            template = p.trsf_folder + "tmp.klb"
+            template = os.path.join(p.trsf_folder, "tmp.klb")
             res_t = "template.klb"
         else:
-            template = p.trsf_folder + "tmp.tif"
+            template = os.path.join(p.trsf_folder, "tmp.tif")
             res_t = "template.tif"
 
         imsave(template, im)
@@ -794,26 +777,21 @@ class TimeRegistration:
         new_trsf_fmt_no_flo = new_trsf_fmt.replace("{flo:06d}", "%06d")
         for t in p.not_to_do:
             np.savetxt(
-                p.trsf_folder + trsf_fmt.format(flo=t, ref=p.ref_TP), identity
+                os.path.join(p.trsf_folder, trsf_fmt.format(flo=t, ref=p.ref_TP), identity)
             )
 
         call(
             p.path_to_bin
             + "changeMultipleTrsfs -trsf-format "
-            + p.trsf_folder
-            + trsf_fmt_no_flo.format(ref=p.ref_TP)
+            + os.path.join(p.trsf_folder, trsf_fmt_no_flo.format(ref=p.ref_TP))
             + " -index-reference %d -first %d -last %d "
             % (p.ref_TP, min(p.time_points), max(p.time_points))
             + " -template "
             + template
-            + " "
             + " -res "
-            + p.trsf_folder
-            + new_trsf_fmt_no_flo.format(ref=p.ref_TP)
+            + os.path.join(p.trsf_folder, new_trsf_fmt_no_flo.format(ref=p.ref_TP))
             + " -res-t "
-            + p.trsf_folder
-            + res_t
-            + " "
+            + os.path.join(p.trsf_folder, res_t)
             + " -trsf-type %s -vs %f %f %f" % ((p.trsf_type,) + p.voxel_size),
             shell=True,
         )
@@ -848,7 +826,7 @@ class TimeRegistration:
                         list(p.to_register),
                     )
             np.savetxt(
-                ("{:s}" + trsf_fmt).format(
+                os.path.join("{:s}", trsf_fmt).format(
                     p.trsf_folder, flo=p.ref_TP, ref=p.ref_TP
                 ),
                 np.identity(4),
@@ -880,10 +858,10 @@ class TimeRegistration:
         if p.padding:
             trsf_fmt = "t{flo:06d}-{ref:06d}-padded.txt"
             if pyklb_found:
-                template = p.trsf_folder + "template.klb"
+                template = os.path.join(p.trsf_folder, "template.klb")
                 X, Y, Z = readheader(template)["imagesize_tczyx"][-1:-4:-1]
             else:
-                template = p.trsf_folder + "template.tif"
+                template = os.path.join(p.trsf_folder, "template.tif")
                 X, Y, Z = imread(template).shape
         elif p.A0.split(".")[-1] == "klb":
             X, Y, Z = readheader(p.A0.format(t=p.ref_TP))["imagesize_tczyx"][
@@ -905,12 +883,11 @@ class TimeRegistration:
                 p.path_to_bin
                 + "applyTrsf '%s' '%s' -trsf "
                 % (p.A0.format(t=t), p.A0_out.format(t=t))
-                + p.trsf_folder
-                + trsf_fmt.format(flo=t, ref=p.ref_TP)
+                + os.path.join(p.trsf_folder, trsf_fmt.format(flo=t, ref=p.ref_TP))
                 + " -template "
                 + template
                 + " -floating-voxel %f %f %f " % p.voxel_size
-                + " -reference-voxel %f %f %f " % p.voxel_size
+                + " -reference-voxel %f %f %f " % p.voxel_size_out
                 + " -interpolation %s" % p.image_interpolation,
                 shell=True,
             )
@@ -929,15 +906,15 @@ class TimeRegistration:
             if not os.path.exists(p_to_data.format(t=-1)):
                 os.makedirs(p_to_data.format(t=-1))
             imsave(
-                (p_to_data + f_name.replace(p.im_ext, "xyProjection.tif")),
+                os.path.join(p_to_data, f_name.replace(p.im_ext, "xyProjection.tif")),
                 SpatialImage(xy_proj),
             )
             imsave(
-                (p_to_data + f_name.replace(p.im_ext, "xzProjection.tif")),
+                os.path.join(p_to_data, f_name.replace(p.im_ext, "xzProjection.tif")),
                 SpatialImage(xz_proj),
             )
             imsave(
-                (p_to_data + f_name.replace(p.im_ext, "yzProjection.tif")),
+                os.path.join(p_to_data, f_name.replace(p.im_ext, "yzProjection.tif")),
                 SpatialImage(yz_proj),
             )
 
@@ -1146,7 +1123,7 @@ class TimeRegistration:
         tX, tY, tZ = [], [], []
         rX, rY, rZ = [], [], []
         for t in sorted(p.time_points):
-            trsf = self.read_trsf(p.trsf_folder + trsf_fmt.format(flo=t, ref=p.ref_TP))
+            trsf = self.read_trsf(os.path.join(p.trsf_folder, trsf_fmt.format(flo=t, ref=p.ref_TP)))
             (tx, ty, tz), M, *_ = decompose(trsf)
             rx, ry, rz = mat2euler(M)
             tX.append(tx)
